@@ -5,7 +5,7 @@ import pandas as pd
 """
 Created on October 2020
 
-@email: huangke@shangahitech.edu.cn
+@email: tanxinjiang2019@sibs.ac.cn 
 
 """
 description= \
